#
# spec file for package ibus-sunpinyin
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ibus-sunpinyin
Version:        2.0.99.2
Release:        4.3
Summary:        Sunpinyin module for ibus
License:        CDDL-1.0 OR LGPL-2.1-only
Group:          System/I18n/Chinese
URL:            https://github.com/sunpinyin/sunpinyin
Source:         https://github.com/sunpinyin/sunpinyin/archive/v3.0.0-rc2/sunpinyin-3.0.0-rc2.tar.gz
# PATCH-FIX-UPSTREAM ibus-sunpinyin-fix-libexecdir.patch hillwood@opensuse.org -- libexecdir should be in %{_libdir}/ibus/
Patch0:         ibus-sunpinyin-fix-libexecdir.patch
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  scons >= 1.2.0
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(sunpinyin-2.0)
Requires:       sunpinyin-data
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
ibus-sunpinyin is a wrapper around SunPinyin which enables user to use
SunPinyin with IBus framework.

%prep
%autosetup -p1 -n sunpinyin-3.0.0-rc2
sed -i "s/LIBEXECDIR'\].*ibus-sunpinyin.*/LIBEXECDIR'\]/" SConstruct
sed -i "s/exec python /exec python3 /g" wrapper/ibus/setup/ibus-setup-sunpinyin.in

%build
cd wrapper/ibus/
scons --prefix=%{_prefix} \
      --libdir=%{_libdir} \
      --libexecdir=%{_ibus_libexecdir}

%install
pushd wrapper/ibus/
scons install --prefix=%{_prefix} \
              --libdir=%{_libdir} \
              --libexecdir=%{_ibus_libexecdir} \
              --install-sandbox=%{buildroot}
popd

chmod 755 %{buildroot}%{_datadir}/%{name}/setup/main.py

%find_lang %{name}

%files -f %{name}.lang
%defattr(-,root,root)
%doc wrapper/ibus/README
%license wrapper/ibus/COPYING wrapper/ibus/LGPL.LICENSE wrapper/ibus/OPENSOLARIS.LICENSE
%{_ibus_libexecdir}/ibus-engine-sunpinyin
%{_ibus_libexecdir}/ibus-setup-sunpinyin
%{_datadir}/%{name}
%{_datadir}/ibus/component/sunpinyin.xml

%changelog
* Sat Jan 20 2024 Callum Farmer <gmbr3@opensuse.org>
- Fixes for %%_ibus_libexecdir moving to %%_libexecdir (bsc#1174075)
* Wed Dec 15 2021 Cliff Zhao <qzhao@suse.com>
- Remove locale macro in SPEC: disable default installation, allow
  the end user to choose install or not (jsc#SLE-3872).
* Thu Nov  4 2021 Hillwood Yang <hillwood@opensuse.org>
- Fix ibus-sunpinyin-setup can not launch.
* Mon Nov  1 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.0.0-RC2(2.0.99.2)
  * Port to Python3. Drop ibus-sunpinyin-migrate-to-python3.patch
    and ibus-sunpinyin-scons-on-py3.patch
  * drop deprecated "use-stock" property
  * use GtkScale instead of deprecated GtkHScale
  * update using glade 3.38
* Fri Mar  6 2020 Hillwood Yang <hillwood@opensuse.org>
- Add ibus-sunpinyin-fix-libexecdir.patch: Fix libexecdir path,
  add ibus-sunpinyin.changes libexecdir should be in
  %%{_libdir}/ibus/ for ibus.
* Tue Mar  3 2020 Hillwood Yang <hillwood@opensuse.org>
- Use python3, python2 is EOF. Add ibus-sunpinyin-migrate-to-python3.patch
* Fri Apr 13 2018 hillwood@opensuse.org
- Drop Provides tag, make sure python2 won't be automatically installed
* Thu Nov 23 2017 dimstar@opensuse.org
- Add ibus-sunpinyin-scons-on-py3.patch: Fix build with scons using
  pythoh3 as interpreter.
* Tue Sep 12 2017 hillwood@opensuse.org
- Update to 3.0.0rc1
  * fixed the cursor_up(): ccd1cd1
  * added the setup tag: a43d055
  * add init status prefs: 0876aee
  * hacks for working on GNOME3.6 with Emacs: 346afe8
  * fixed garble menu label for ibus wrapper: 40b66fb
- Fix Doc filelist
* Thu Jun  1 2017 qzhao@suse.com
- Update ibus-sunpinyin.spec add install requires to sunpinyin-data
  which is necessary for sunpinyin running (boo#1042182).
* Wed May 24 2017 qzhao@suse.com
- Add is_opensuse macro in SPEC file, limit sunpinyin installation
  not by default in SLE.
* Sun Jul 21 2013 hillwood@linuxfans.org
- And python-ibus as Requires.
* Tue May  7 2013 i@marguerite.su
- remove unnessary Requires.
* Sat Apr 27 2013 i@marguerite.su
- fix the crappy libexecdir.
  * no longer install to /usr/lib/ibus-sunpinyin,
    even on a x86_64 system. install %%{_libdir}/ibus instead.
* Sat Jun  2 2012 hillwood@linuxfans.org
- bring ibus-sunpinyin as default in DVD.
- add Provides(ibus:zh)
* Thu Feb 16 2012 cfarrell@suse.com
- license update: LGPL-2.1 or CDDL-1.0
  Look at the license file - it is a choice of LGPL-2.1, not GPL-2.0. Also,
  use SPDX format
* Mon Aug  1 2011 tiwai@suse.de
- Fix build on FACTORY
- Clean up spec file
* Fri Jul 29 2011 hillwood@linuxfans.org
- Move changelog to a single file
* Thu Feb 24 2011 hillwood@linuxfans.org
- new release 2.0.3
